#ifndef __PVPLUS_H
#define __PVPLUS_H

#ifndef PV
    #ifdef WIN32
    typedef HANDLE VIEW;
    typedef int  VWFIELD;
    #else
    typedef HANDLE VIEW;
    typedef int  VWFIELD;
    #endif
#endif

typedef int  FIELDNO;
typedef LRESULT (CALLBACK *VIEWPROC)(HWND, UINT, WPARAM, LPARAM);
typedef LRESULT (CALLBACK *FIELDPROC)(HWND, UINT, WPARAM, LPARAM);

#define DLGC_WANTPVMESSAGES  0x8000        // Control wants ProtoView specific messages

// Notification messages and codes
#define VW_APPTOSCR        WM_USER + 0x900 // Convert variable to screen string, variable is pointed to by lParam
#define VW_SCRTOAPP        WM_USER + 0x901 // Convert screen string to variable, variable is pointed to by lParam

//#ifdef WIN32
#define VW_SETFIELDSTRING  WM_USER + 0x122 // Set Field string, string is pointed to by lParam
#define VW_SETVIEWSTRING   WM_USER + 0x123
//#else
//#define VW_SETFIELDSTRING  WM_USER + 0x902 // Set Field string, string is pointed to by lParam
//#define VW_SETVIEWSTRING   WM_USER + 0x903
//#endif
#define VW_GETFIELDSTRING  WM_USER + 0x904 // Place field string into lParam pointer
#define VW_EDITFIELD       WM_USER + 0x905 // Field should edit its contents and set View error status
#define VW_GETTEXTLIMIT    WM_USER + 0x906
#define VW_GETFIELDINFO    WM_USER + 0x907 // Return the number of bytes for
                                           // field variable and place variable
#define WM_CTLCOLORVWSELECT WM_USER + 0x908  // WM_CTLCOLOR for Selected color in controls

// Error State values
#define VW_ERRORSET        WM_USER + 0x909
#define VW_ERRORCLEAR      WM_USER + 0x910

// Drag and Drop Notifications
#define VW_DRAGSOURCE      WM_USER + 0x911
#define VW_DROPTARGET      WM_USER + 0x912
#define VW_WANTDROP        WM_USER + 0x913
#define VW_DROPREMOVE      WM_USER + 0x914

#define VW_GETRESOURCEFULLPATH WM_USER + 0x915  // Used internally by workbench

// Error Status values
#define VWERR_NOTENTERED   100
#define VWERR_NOTFILLED    200
#define VWERR_RANGE        300
#define VWERR_NOTVALID     400
#define VWERR_NOTCHOICE    500
#define VWERR_NOTFOUND     600

// Error handling return codes
#define VWERROR_NOTPROCESSED      0
#define VWERROR_PROCESSED         1
#define VWERROR_WARNING           2
#define VWERROR_IGNORE            4

// Error display values
#define VE_POPUP           0x20
#define VE_LOOKUP          0x40
#define VE_MSGBOX          0x80
#define VE_MBOX            0x80
#define VE_BEEP            0x100

// return values for VW_EDITFIELD
#define VW_ERROR           -1
#define VW_NOERROR         0

// Definitions for vwSetViewPosition() and vwBalloonMsg() flags
#define VW_SCREENCOORD     0x01
#define VW_SIZEPARENT      0x02
#define VW_DLGCOORD        0x04
#define VW_ABSALIGN        0x08
#define VW_SCREENCENTER    0x10
#define VW_REPAINT         0x20
#define VW_COLOR           0x40
#define VW_NOSHADOW        0x80
#define VW_SQUARESHAPE     0x100
#define VW_SINGLELINE      0x200
#define VW_MOUSECLOSE      0x400

// Data type definitions for vwValidate function
#define VW_INTEGER           1
#define VW_LONG              2
#define VW_DOUBLE            3
#define VW_STRING            4
#define VW_DATE              5
#define VW_TIME              6
#define VW_REAL              7
#define VW_FLOAT             9
#define VW_CHAR             10
#define VW_TMSTRUCT         11
#define VW_LONGDOUBLE       12
#define VW_DATE_MMDDYY      13
#define VW_DATE_MMDDYYYY    14
#define VW_DATE_DDMMYY      15
#define VW_DATE_DDMMYYYY    16
#define VW_DATE_YYMMDD      17
#define VW_DATE_YYYYMMDD    18
#define VW_LBARRAY          19
#define VW_CBARRAY          20
#define VW_DATETIME         21
#define VW_VARCHAR          22
#define VW_BINARY           23
#define VW_VARBINARY        24
#define VW_SHORT            25

typedef unsigned short          VWTYPE;
typedef unsigned short FAR *    LPVWTYPE;

// Date Conversion type values
#define MMDDYY    0x01
#define MMDDYYYY  0x02
#define DDMMYY    0x04
#define DDMMYYYY  0x08
#define YYMMDD    0x10
#define YYYYMMDD  0x20

// Font Style definitions
#define FS_BOLD            1
#define FS_ITALIC          2
#define FS_UNDERLINE       4
#define FS_STRIKEOUT       8

// Toolbar style definitions
#ifndef WIN32
#define TB_LEFT            1
#define TB_RIGHT           2
#define TB_TOP             4
#define TB_BOTTOM          8
#endif

// Alternate Toolbar style definitions to avoid commctrl.h conflicts
#define PV_LEFT            1
#define PV_RIGHT           2
#define PV_TOP             4
#define PV_BOTTOM          8

// Dynamic Status Line definitions
#define DSL_VIEW          0x04
#define DSL_TOP_TB        0x08
#define DSL_BOTTOM_TB     0x010
#define DSL_FILE          0x020
#define DSL_RESOURCE      0x040

#define CN_COLORCHANGE      0x050  // Color control notification message
#define CTLCOLOR_VWSELECT   0x050  // WM_CTLCOLOR for Selected color in controls
#define DM_GETDATEFORMAT    WM_USER + 10  // Date control format retrieval message


// Flags for Table functions
#define TABLE_FILE         0x00
#define TABLE_RESOURCE     0x08

#define MAX_FIELD_LEN    160       // Maximum Field length
#define ITEM_NAME_MAX_SIZE  50     // Maximum DDE identifier length

// vwPrintFile() and vwPrintBuffer() error codes
#define VW_MEM_ERROR         1
#define VW_FILE_OPEN_ERROR   2
#define VW_FILE_READ_ERROR   3
#define VW_PRINTER_ERROR     4
#define VW_DLG_CREATE_ERROR  5

// vwPrintFileExt() and vwPrintBufferExt() flags
#define   VW_PRINT_OPT_NODLG    2
#define   VW_PRINT_OPT_OWN_DC   4

// Defines for CopyFile() return codes
#define FILE_ERROR 1
#define OUT_OF_DISK_SPACE 2

// Defines for vwEditFile() messages
#define VW_GETEDITORWINDOW  WM_USER+100
#define VW_MODELESS         0x000
#define VW_MODAL            0x001
#define VW_NOSHOW           0x002

// Macros to define common rgb colors
#define rgbRED     RGB(255, 0, 0)
#define rgbGREEN   RGB(0, 255, 0)
#define rgbBLUE    RGB(0, 0, 255)
#define rgbYELLOW  RGB(255, 255, 0)
#define rgbCYAN    RGB(0, 255, 255)
#define rgbWHITE   RGB(255, 255, 255)
#define rgbBLACK   RGB(0, 0, 0)
#define rgbGRAY    RGB(192, 192, 192)

// Macros for sending and receiving WM_COMMAND messages for NT and Win 3.x
// Also, macros for getting and setting window word and long values.
#define WINDOW_PARAMS   HWND hWnd, UINT wMessage, WPARAM wParam, LPARAM lParam
#ifdef WIN32
    #define SENDCOMMAND(hWnd, Id, Notify, CtlWnd)  SendMessage(hWnd, WM_COMMAND, MAKELONG(Id, Notify), (LPARAM)CtlWnd)
    #define WMCOMMAND(wParam, lParam)   case WM_COMMAND : { WORD Id, Notify; HWND CtlWnd; Id = LOWORD(wParam); Notify = HIWORD(wParam); CtlWnd = (HWND)lParam;
    #define COMMAND_PARAMS(wParam, lParam)   WORD Id, Notify; HWND CtlWnd; Id = LOWORD(wParam); Notify = HIWORD(wParam); CtlWnd = (HWND)lParam;
    #define GET_INSTANCE(hWnd)   (HINSTANCE)GetWindowLong(hWnd, GWL_HINSTANCE)
    #define SET_INSTANCE(hWnd, hInstance)   SetWindowLong(hWnd, GWL_HINSTANCE, (LONG)hInstance)
    #define GET_CLASSICON(hWnd)   (HICON)GetClassLong(hWnd, GCL_HICON)
    #define SET_CLASSICON(hWnd, hIcon)   (HICON)SetClassLong(hWnd, GCL_HICON, (LONG)hIcon)
    #define GET_CLASSCURSOR(hWnd)   (HCURSOR)GetClassLong(hWnd, GCL_HCURSOR)
    #define SET_CLASSCURSOR(hWnd, hCursor)   (HCURSOR)SetClassLong(hWnd, GCL_HCURSOR, (LONG)hCursor)
    #define GET_CLASSBRUSH(hWnd)   (HBRUSH)GetClassLong(hWnd, GCL_HBRBACKGROUND)
    #define SET_CLASSBRUSH(hWnd, hBrush)   (HBRUSH)SetClassLong(hWnd, GCL_HBRBACKGROUND, (LONG)hBrush)
    #define GET_ID(hWnd)  GetWindowLong(hWnd, GWL_ID)
    #define SET_ID(hWnd, x)  SetWindowLong(hWnd, GWL_ID, (LONG)x)
    #define SETFONT(hWnd, x)   SetWindowLong(hWnd, GWL_HFONT, (LONG)x)
    #define GETFONT(hWnd)                   (HFONT)GetWindowLong(hWnd, GWL_HFONT)
    #define SETPARENT(hWnd, x)   SetWindowLong(hWnd, GWL_HWNDPARENT, (LONG)x)
    #define GETPARENT(hWnd)    (HWND)GetWindowLong(hWnd, GWL_HWNDPARENT)
    #define SEND_EM_SETSEL(hWnd, x, y) SendMessage(hWnd, EM_SETSEL, x, y)
#else
    #define SENDCOMMAND(hWnd, Id, Notify, CtlWnd)  SendMessage(hWnd, WM_COMMAND, Id, MAKELONG(CtlWnd, Notify))
    #define WMCOMMAND(wParam, lParam)   case WM_COMMAND : { WORD Id, Notify; HWND CtlWnd; Id = wParam; Notify = HIWORD(lParam); CtlWnd = (HWND)LOWORD(lParam);
    #define COMMAND_PARAMS(wParam, lParam)   WORD Id, Notify; HWND CtlWnd; Id = wParam; Notify = HIWORD(lParam); CtlWnd = (HWND)LOWORD(lParam);
    #define GET_INSTANCE(hWnd)   (HINSTANCE)GetWindowWord(hWnd, GWW_HINSTANCE)
    #define SET_INSTANCE(hWnd, hInstance)   (HINSTANCE)SetWindowWord(hWnd, GWW_HINSTANCE, (WORD)hInstance)
    #define GET_CLASSICON(hWnd)   (HICON)GetClassWord(hWnd, GCW_HICON)
    #define SET_CLASSICON(hWnd, hIcon)   (HICON)SetClassWord(hWnd, GCW_HICON, (WORD)hIcon)
    #define GET_CLASSCURSOR(hWnd)   (HCURSOR)GetClassWord(hWnd, GCW_HCURSOR)
    #define SET_CLASSCURSOR(hWnd, hCursor)   (HCURSOR)SetClassWord(hWnd, GCW_HCURSOR, (WORD)hCursor)
    #define GET_CLASSBRUSH(hWnd)   (HBRUSH)GetClassWord(hWnd, GCW_HBRBACKGROUND)
    #define SET_CLASSBRUSH(hWnd, hBrush)   (HBRUSH)SetClassWord(hWnd, GCW_HBRBACKGROUND, (WORD)hBrush)
    #define GET_ID(hWnd)  GetWindowWord(hWnd, GWW_ID)
    #define SET_ID(hWnd, x)  SetWindowWord(hWnd, GWW_ID, (WORD)x)
    #define SETFONT(hWnd, x)   SetWindowWord(hWnd, GWW_HFONT, (WORD)x)
    #define GETFONT(hWnd)                   (HFONT)GetWindowWord(hWnd, GWW_HFONT)
    #define SETPARENT(hWnd, x) SetWindowWord(hWnd, GWW_HWNDPARENT, (WORD)x)
    #define GETPARENT(hWnd)   (HWND)GetWindowWord(hWnd, GWW_HWNDPARENT)
    #define SEND_EM_SETSEL(hWnd, x, y) SendMessage(hWnd, EM_SETSEL, 0, MAKELONG(x, y))
#endif

// Type definition for ListBox interface data structure.
typedef struct LBARRAYtag {
      int  Offset;               // Current Selection, 0 based.
      char FAR *SelectedString;  // Pointer to selected string
      char FAR * FAR * Strings;  // Pointer to array of strings to be loaded.
} LBARRAY;

// Type definition for ComboBox interface data structure.
typedef struct CBARRAYtag {
      int  Offset;                // Current Selection, 0 based
      char FAR * SelectedString;  // Pointer to Editbox contents.
      char FAR * FAR * Strings;   // Pointer to array of strings to be loaded.
} CBARRAY;

// Error handling structure
typedef struct VWERRORtag {
    HWND   hWnd;                  // Error field window
    int    CtlID;                 // Error field ID
    int    DataType;              // Data type of field control
    int    ErrorType;             // Type of error that has ocurred
    LPSTR  szMethods;             // Method string
    LPSTR  szMsg;                 // Message text
    LPSTR  szCaption;             // Caption text
    int    x, y, cx, cy;          // Position values
    LONG   TextColor;             // Text color
    LONG   BackColor;             // Background color
    HFONT  hFont;                 // Text font
    LONG   lFlags;                // Style flags
} VWERROR;

typedef VWERROR FAR *PVWERROR;

// Error handling return codes
#define VWERROR_PROCESSED         1
#define VWERROR_WARNING           2
#define VWERROR_IGNORE            4

// Drag and Drop Styles
#define DDS_MOVE                  0x01
#define DDS_COPY                  0x02
#define DDS_APPEND                0x04
#define DDS_INSERT                0x08
#define DDS_PASTE                 0x10

// Type definition for Drag and Drop interface data structure.
typedef struct DRAGDROPtag {
	  HWND     hWndSource;
	  FIELDNO  SourceID;
	  LONG     lStyle;
	  LONG     lDataType;
      char     szDragChannel[30];
	  HCURSOR  hMoveCur;
	  HCURSOR  hDragCur;
	  HCURSOR  hNoDropCur;
	  HGLOBAL  hData;
} DRAGDROP;
typedef DRAGDROP FAR *LPDRAGDROP;

// Macro definitions for obtaining View and Field number parameters from
// within ViewProcs and FieldProcs.

#define GETVIEW   VIEW View = vwGetView(hWnd)
#define GETFIELD  VWFIELD Field = GET_ID(hWnd)

#define vwGetMacroParm(x,y,z)    vwGetMethodParam(x,y,z)
#define vwUnHideField(x, y) vwUnhideField(x, y)
#define vwUnHideTextField(x, y, z) vwUnhideTextField(x, y, z)
#define vwUnHideView(x) vwUnhideView(x)
#define vwUnProtectField(x, y) vwUnprotectField(x, y)
#define vwSetViewErrorStatus(x, y, z) vwSetViewStatus(x, y, z)

#ifdef __cplusplus
extern "C" {            /* Assume C declarations for C++ */
#endif  /* __cplusplus */

BOOL      WINAPI RegistervwWndProc(HINSTANCE);

// Default message processing function declarations for winctl.dll field controls
LRESULT CALLBACK DefEditProc (HWND, UINT, WPARAM, LPARAM);
LRESULT CALLBACK DefListBoxProc (HWND, UINT, WPARAM, LPARAM);
LRESULT CALLBACK DefComboBoxProc (HWND, UINT, WPARAM, LPARAM);
LRESULT CALLBACK DefStaticProc (HWND, UINT, WPARAM, LPARAM);
LRESULT CALLBACK DefScrollProc (HWND, UINT, WPARAM, LPARAM);
LRESULT CALLBACK DefButtonProc (HWND, UINT, WPARAM, LPARAM);
LRESULT CALLBACK DefViewProc(HWND, UINT, WPARAM, LPARAM);
LRESULT CALLBACK DefFrameViewProc(HWND, HWND, UINT, WPARAM, LPARAM);
LRESULT CALLBACK DefMDIChildViewProc(HWND, UINT, WPARAM, LPARAM);
LRESULT CALLBACK EditFileViewProc(HWND, UINT, WPARAM, LPARAM);

VOID      WINAPI DisplayDIBitmap(HWND,HDC,HANDLE,int,int);
HANDLE    WINAPI ICORead(HANDLE, HWND,char far *);

//  Function declarations for ProtoView utility functions
#ifdef WIN32

LPTSTR    WINAPI lstrncpy(LPSTR, LPCSTR, int);
LPTSTR    WINAPI lstrchr(LPSTR, char);
int       WINAPI lstrdigits(LPTSTR);
int       WINAPI lstrncmp(LPCSTR, LPCSTR, int);
int       WINAPI lstricmp(LPCSTR, LPCSTR);
int       WINAPI lstrnicmp(LPCSTR, LPCSTR, int);
void      WINAPI lstrpad(LPSTR, int);
LPTSTR    WINAPI lstrright(LPSTR, int);
LPTSTR    WINAPI lstristr(LPCSTR, LPCSTR);
LPTSTR    WINAPI lstrpreclip(LPSTR);
LPTSTR    WINAPI lstrminus(LPSTR);
LPTSTR    WINAPI lstrclip(LPSTR);
WORD      WINAPI lstrcount(LPSTR, char);
LPTSTR    WINAPI lstrnocomma(LPSTR, char);
LPTSTR    WINAPI lstrcomma(LPSTR, char, char);
LPTSTR    WINAPI lstrnodecp(LPSTR, char);
LPTSTR    WINAPI lstrdecp(LPSTR, int, char);
LPTSTR    WINAPI lstrremove(LPSTR, LPCSTR);
LPTSTR    WINAPI lstrremovestr(LPSTR, LPCSTR);
#else
LPSTR     WINAPI lstrncpy(LPSTR, LPSTR, int);
LPSTR     WINAPI lstrchr(LPSTR, char);
int       WINAPI lstrdigits(LPSTR);
int       WINAPI lstrncmp(LPSTR, LPSTR, int);
int       WINAPI lstricmp(LPSTR, LPSTR);
int       WINAPI lstrnicmp(LPSTR, LPSTR, int);
void      WINAPI lstrpad(LPSTR, int);
LPSTR     WINAPI lstrright(LPSTR, int);
LPSTR     WINAPI lstristr(LPSTR, LPSTR);
LPSTR     WINAPI lstrpreclip(LPSTR);
LPSTR     WINAPI lstrminus(LPSTR);
LPSTR     WINAPI lstrclip(LPSTR);
WORD      WINAPI lstrcount(LPSTR, char);
LPSTR     WINAPI lstrnocomma(LPSTR, char);
LPSTR     WINAPI lstrcomma(LPSTR, char, char);
LPSTR     WINAPI lstrnodecp(LPSTR, char);
LPSTR     WINAPI lstrdecp(LPSTR, int, char);
LPSTR     WINAPI lstrremove(LPSTR, LPSTR);
LPSTR     WINAPI lstrremovestr(LPSTR, LPSTR);
#endif
// Function declarations for the WinCtl Control Library
BOOL      WINAPI vwAddMethodParam(LPSTR, LPSTR);
HBITMAP   WINAPI vwBitmapFromDib(HANDLE, HPALETTE FAR *);
BOOL      WINAPI vwClipboardCopyText(HWND, LPSTR, int);
BOOL      WINAPI vwClipboardPasteText(HWND, LPSTR, int);
int       WINAPI vwCopyFile(LPSTR, LPSTR);
int       WINAPI vwDateCmp(struct tm far *, struct tm far *);
void      WINAPI vwDateToTM(struct tm far *, LPSTR, int);
char      WINAPI vwDeleteChar(LPSTR, int);
BOOL      WINAPI vwFreeTable(HGLOBAL);
BOOL      WINAPI vwGetMethodParam(LPSTR, LPSTR, LPSTR);
HWND      WINAPI vwGetModuleWindow(LPSTR);
BOOL      WINAPI vwInitiateDDE(HWND, LPSTR);
BOOL      WINAPI vwIsDateValid(struct tm far *t);
void      WINAPI vwInsertChar(LPSTR, int, int);
BOOL      WINAPI vwIsTimeValid(struct tm far *t);
HBITMAP   WINAPI vwLoadDIBitmap(HINSTANCE, LPCSTR, HPALETTE FAR *);
char      WINAPI vwOverWriteChar(LPSTR, char, int);
LONG      WINAPI vwProcessDDE(HWND, UINT, WPARAM, LONG, LPSTR);
BOOL      WINAPI vwProcessDDEData(HWND, LPSTR);
BOOL      WINAPI vwRequestDDEData(HWND);
LRESULT   WINAPI vwProcessDragDrop(HWND, UINT, WPARAM, LPARAM);
BOOL      WINAPI vwRemoveMethodParam(LPSTR, LPSTR);
HGLOBAL   WINAPI vwSearchTable(LPSTR, int, LPSTR, char, HINSTANCE, LONG);
void      WINAPI vwUnadviseDDE(HWND);
BOOL      WINAPI vwValidate(HWND, int, void far *, LPSTR, LPSTR);
BOOL      WINAPI vwValidateRange(int, void far *, LPSTR);
BOOL      WINAPI vwValidateChoice(int, void far *, LPSTR);

#ifdef __USESCREEN

// Function declarations for ProtoView Function Library
BOOL      WINAPI vwAnimateField(VIEW, VWFIELD, int, int, WORD, WORD, WORD);
HWND      WINAPI vwBalloonMsg(HWND, LPSTR, int, int, int, int, HFONT, LONG, LONG, LONG);
HWND      WINAPI vwBrowse(HGLOBAL, LPSTR, LPSTR, LPSTR, LPSTR, int, int, int, int, int, WORD, DLGPROC);
HFONT     WINAPI vwCreateFont(LPSTR, WORD, WORD);
VIEW      WINAPI vwCreateView(HINSTANCE, LPCSTR, HWND, VIEWPROC, void FAR *);
VIEW      WINAPI vwCreateMDIChildView(HINSTANCE, LPCSTR, HWND, VIEWPROC, MDICREATESTRUCT FAR *);
BOOL      WINAPI vwDeleteField(VIEW, VWFIELD);
BOOL      WINAPI vwDeleteTextField(VIEW, VWFIELD);
void      WINAPI vwDialogToScreen(LPRECT);
void      WINAPI vwDoAppToScr(VIEW, VWFIELD);
void      WINAPI vwDoScrToApp(VIEW, VWFIELD);
BOOL      WINAPI vwEditField(VIEW, VWFIELD);
HWND      WINAPI vwEditFile(HWND, LPSTR, LPSTR, int, int, int, int, int);
BOOL      WINAPI vwEditView(VIEW);
void      WINAPI vwEndModalView(VIEW, int);
void      WINAPI vwFreeView(VIEW);
HGLOBAL   WINAPI vwFileOpenDlg (HWND, LPSTR, LPSTR, WORD, DLGPROC);
HGLOBAL   WINAPI vwFileSaveDlg (HWND, LPSTR, LPSTR, WORD FAR *, DLGPROC);
WORD      WINAPI vwGetAllocFieldString(VIEW, VWFIELD, LPSTR, int);
WORD      WINAPI vwGetCancelButton(VIEW View);
VWFIELD   WINAPI vwGetCurrField(VIEW);
LPSTR     WINAPI vwGetCurrVar(VIEW);
FIELDPROC WINAPI vwGetDefFieldProc(VIEW, VWFIELD);
HWND      WINAPI vwGetDSLWindow(VIEW);
VWFIELD   WINAPI vwGetField(VIEW, HWND);
HBRUSH    WINAPI vwGetFieldBackBrush(VIEW, VWFIELD);
LONG      WINAPI vwGetFieldBkColor(VIEW, VWFIELD);
BOOL      WINAPI vwGetFieldColors(VIEW, VWFIELD, LONG FAR*, LONG FAR*, LONG FAR*, LONG FAR*);
int       WINAPI vwGetFieldCount(VIEW);
WORD      WINAPI vwGetFieldDlgCode(VIEW, VWFIELD);
int       WINAPI vwGetFieldFromID(VIEW, VWFIELD);
int       WINAPI vwGetFieldHeight(VIEW, VWFIELD);
VWFIELD   WINAPI vwGetFieldID(VIEW, void FAR *);
VWFIELD   WINAPI vwGetFieldIDFromName(VIEW, LPSTR);
WORD      WINAPI vwGetFieldLimit(VIEW, VWFIELD);
BOOL      WINAPI vwGetFieldModified(VIEW, VWFIELD);
LPSTR     WINAPI vwGetFieldName(VIEW, VWFIELD);
BOOL      WINAPI vwGetFieldNameFromID(VIEW, VWFIELD, LPSTR, int);
VWFIELD   WINAPI vwGetFieldNo(VIEW, void FAR *);
HWND      WINAPI vwGetFieldNoWindow(VIEW, VWFIELD);
FIELDPROC WINAPI vwGetFieldProc(VIEW, VWFIELD);
HBRUSH    WINAPI vwGetFieldSelBackBrush(VIEW, VWFIELD);
LONG      WINAPI vwGetFieldSelBkColor(VIEW, VWFIELD);
LONG      WINAPI vwGetFieldSelTextColor(VIEW, VWFIELD);
WORD      WINAPI vwGetFieldString(VIEW, VWFIELD, LPSTR, int);
LONG      WINAPI vwGetFieldTextColor(VIEW, VWFIELD);
void FAR *WINAPI vwGetFieldVar(VIEW, VWFIELD);
int       WINAPI vwGetFieldWidth(VIEW, VWFIELD);
VWFIELD   WINAPI vwGetFieldWndNo(VIEW, HWND);
HWND      WINAPI vwGetFieldWindow(VIEW, VWFIELD);
int       WINAPI vwGetFieldXPos(VIEW, VWFIELD);
int       WINAPI vwGetFieldYPos(VIEW, VWFIELD);
BOOL      WINAPI vwGetFontFlags(LPSTR, BYTE far *, BYTE far *);
int       WINAPI vwGetIDFromField(VIEW, VWFIELD);
WORD      WINAPI vwGetOKButton(VIEW);
HDC       WINAPI vwGetPrinterDC(void);
LPSTR     WINAPI vwGetSQLVarName(VIEW, VWFIELD);
HWND      WINAPI vwGetSQLVarWnd(VIEW, LPSTR);
VWFIELD   WINAPI vwGetSQLVarId(VIEW, LPSTR);

BOOL      WINAPI vwGetTextFieldColors(VIEW, VWFIELD, LONG FAR *, LONG FAR *);
int       WINAPI vwGetTextFieldCount(VIEW);
HFONT     WINAPI vwGetTextFieldFont(VIEW, VWFIELD);
void      WINAPI vwGetTextFieldText(VIEW, VWFIELD, LPSTR, int);
int       WINAPI vwGetTextFieldXPos(VIEW, VWFIELD);
int       WINAPI vwGetTextFieldYPos(VIEW, VWFIELD);
VIEW      WINAPI vwGetView(HWND);
HBRUSH    WINAPI vwGetViewBackBrush(VIEW);
void      WINAPI vwGetViewDefColors(VIEW, LONG FAR *, LONG FAR *, LONG FAR *, LONG FAR *);
HANDLE    WINAPI vwGetViewDataHandle(VIEW);
BOOL      WINAPI vwGetViewDropData(VIEW, LPSTR, LPSTR, UINT);
void      WINAPI vwGetViewErrorColors(VIEW, LONG FAR *, LONG FAR *);
WORD      WINAPI vwGetViewErrorStatus(VIEW);
LONG      WINAPI vwGetViewExStyle(VIEW);
int       WINAPI vwGetViewHeight(VIEW View);
HICON     WINAPI vwGetViewIcon(VIEW);
HINSTANCE WINAPI vwGetViewInstance(VIEW);
LONG      WINAPI vwGetViewLongDataHandle(VIEW);
HMENU     WINAPI vwGetViewMenu(VIEW);
HWND      WINAPI vwGetViewParent(VIEW);
VIEWPROC  WINAPI vwGetViewProc(VIEW);
int       WINAPI vwGetViewResourceName(VIEW, LPSTR);
HBRUSH    WINAPI vwGetViewSelBackBrush(VIEW);
WORD      WINAPI vwGetViewString(VIEW, LPSTR, int);
LONG      WINAPI vwGetViewStyle(VIEW);
void far* WINAPI vwGetViewThisPtr(VIEW);
VIEW      WINAPI vwGetViewToolBar(HWND, LONG);
int       WINAPI vwGetViewWidth(VIEW View);
HWND      WINAPI vwGetViewWindow(VIEW);
int       WINAPI vwGetViewXPos(VIEW View);
int       WINAPI vwGetViewYPos(VIEW View);
int       WINAPI vwGotoFirstField(VIEW);
BOOL      WINAPI vwHideField(VIEW, VWFIELD);
BOOL      WINAPI vwHideTextField(VIEW, VWFIELD, BOOL);
BOOL      WINAPI vwHideView(VIEW);
LONG      WINAPI vwInterFieldProc(HWND, UINT, WPARAM, LPARAM);
BOOL      WINAPI vwIsFieldColored(VIEW, VWFIELD);
BOOL      WINAPI vwIsFieldProtected(VIEW, VWFIELD);
BOOL      WINAPI vwIsView(VIEW);
BOOL      WINAPI vwIsViewActive(VIEW);
HGLOBAL   WINAPI vwLoadTable(LPCSTR, WORD, HINSTANCE, WORD, char, LPCSTR, LPCSTR, LONG);
void      WINAPI vwMapDialogToScreen(HWND, LPRECT);
void      WINAPI vwMapScreenToDialog(HWND, LPRECT);
LPSTR     WINAPI vwMessageLookup(VIEW, LPSTR, LPSTR, LONG);
HGLOBAL   WINAPI vwOpenDib(LPSTR);
VIEW      WINAPI vwOpenMDIChildView(HINSTANCE, LPSTR, LONG, HWND, VIEWPROC, MDICREATESTRUCT FAR *);
VIEW      WINAPI vwOpenView(HINSTANCE, LPSTR, LONG, HWND, VIEWPROC, void FAR *);
void      WINAPI vwPaintField(VIEW, VWFIELD);
void      WINAPI vwPaintViewFields(VIEW);
short     WINAPI vwPrintBuffer(HWND, HGLOBAL, LPSTR);
short     WINAPI vwPrintBufferExt(HWND, HGLOBAL, LPSTR, HDC, LONG);
short     WINAPI vwPrintFile(HWND, LPSTR, LPSTR);
short     WINAPI vwPrintFileExt(HWND, LPSTR, LPSTR, HDC, LONG);
void      WINAPI vwProcessDSL(HWND, UINT, WPARAM, LPARAM);
void      WINAPI vwProtectField(VIEW, VWFIELD);
BOOL      WINAPI vwRemoveToolBar(HWND, LONG);
BOOL      WINAPI vwRemoveViewDSL(VIEW);
VWFIELD   WINAPI vwResetField(VIEW, VWFIELD, LPSTR, LPSTR, LONG, int, int, int, int, void FAR *, FIELDPROC);
VWFIELD   WINAPI vwResetFieldEx(VIEW, VWFIELD, LPSTR, LPSTR, LONG, LONG, int, int, int, int, void FAR *, FIELDPROC);
void      WINAPI vwResetFieldColors(VIEW, VWFIELD);
void      WINAPI vwResetViewError(VIEW);
void      WINAPI vwScreenToDialog(LPRECT);
BOOL      WINAPI vwSetAllocFieldString(VIEW, VWFIELD, LPSTR);
VWFIELD   WINAPI vwSetCancelButton(VIEW, VWFIELD);
void      WINAPI vwSetDefFieldProc(VIEW, VWFIELD, FIELDPROC);
void      WINAPI vwSetDefViewProc(VIEW, VIEWPROC);
void      WINAPI vwSetDSLWindow(VIEW, HWND);
VWFIELD   WINAPI vwSetField(VIEW, VWFIELD, LPSTR, LPSTR, LONG, int, int, int, int, void FAR *, FIELDPROC);
VWFIELD   WINAPI vwSetFieldEx(VIEW, VWFIELD, LPSTR, LPSTR, LONG, LONG, int, int, int, int, void FAR *, FIELDPROC);
void      WINAPI vwSetFieldColors(VIEW, VWFIELD, LONG, LONG, LONG, LONG);
void      WINAPI vwSetFieldDlgCode(VIEW, VWFIELD, int);
int       WINAPI vwSetFieldFocus(VIEW, VWFIELD);
HFONT     WINAPI vwSetFieldFont(VIEW, VWFIELD, HFONT);
void      WINAPI vwSetFieldHeight(VIEW, VWFIELD, int, BOOL);
BOOL      WINAPI vwSetFieldID(VIEW, VWFIELD, VWFIELD);
void      WINAPI vwSetFieldLimit(VIEW, VWFIELD, int);
void      WINAPI vwSetFieldModified(VIEW, VWFIELD, BOOL);
BOOL      WINAPI vwSetFieldName(VIEW, VWFIELD, LPSTR);
void      WINAPI vwSetFieldProc(VIEW, VWFIELD, FIELDPROC);
BOOL      WINAPI vwSetFieldString(VIEW, VWFIELD, LPSTR);
void      WINAPI vwSetFieldStyle(VIEW, VWFIELD, long, BOOL);
void      WINAPI vwSetFieldVar(VIEW, VWFIELD, void FAR *);
void      WINAPI vwSetFieldWidth(VIEW, VWFIELD, int, BOOL);
void      WINAPI vwSetFieldXPos(VIEW, VWFIELD, int, BOOL);
void      WINAPI vwSetFieldYPos(VIEW, VWFIELD, int, BOOL);
WORD      WINAPI vwSetFocusNextField(VIEW View);
WORD      WINAPI vwSetFocusPrevField(VIEW View);
VWFIELD   WINAPI vwSetOKButton(VIEW, VWFIELD);
void      WINAPI vwSetSpecialKey(VIEW, DLGPROC);
BOOL      WINAPI vwSetSQLVar(VIEW, VWFIELD, void FAR *, LPSTR);
BOOL      WINAPI vwSetStatusLineId(HWND, VWFIELD);
VWFIELD   WINAPI vwSetTextField(VIEW, int, int, LPSTR, HFONT);
void      WINAPI vwSetTextFieldColors(VIEW, VWFIELD, LONG, LONG);
HFONT     WINAPI vwSetTextFieldFont(VIEW, VWFIELD, HFONT);
void      WINAPI vwSetTextFieldText(VIEW, VWFIELD, LPSTR);
void      WINAPI vwSetTextFieldXPos(VIEW, VWFIELD, int);
void      WINAPI vwSetTextFieldYPos(VIEW, VWFIELD, int);
BOOL      WINAPI vwSetToolBarView(HWND, VIEW, LONG);
void      WINAPI vwSetViewBackBrush(VIEW, HBRUSH);
LONG      WINAPI vwSetViewBkColor(VIEW, LONG);
void      WINAPI vwSetViewCaption(VIEW, LPSTR);
void      WINAPI vwSetViewDataHandle(VIEW, HANDLE);
void      WINAPI vwSetViewDefColors(VIEW, LONG, LONG, LONG, LONG);
BOOL      WINAPI vwSetViewDSL(VIEW, LPSTR, VWFIELD, LONG);
BOOL      WINAPI vwSetViewDSLText(VIEW, LPSTR);
void      WINAPI vwSetViewEditingOff(VIEW);
void      WINAPI vwSetViewEditingOn(VIEW);
BOOL      WINAPI vwSetViewError(VIEW, VWFIELD, LONG, WORD, LPSTR, WORD);
void      WINAPI vwSetViewErrorColors(VIEW, LONG, LONG);
BOOL      WINAPI vwSetViewMessageFile(VIEW, LPSTR);
void      WINAPI vwSetViewExStyle(VIEW, LONG);
BOOL      WINAPI vwSetViewFont(VIEW, LPSTR, int, int, BOOL);
void      WINAPI vwSetViewHeight(VIEW, int, BOOL);
void      WINAPI vwSetViewIcon(VIEW, HICON);
void      WINAPI vwSetViewInstance(VIEW, HINSTANCE);
void      WINAPI vwSetViewLongDataHandle(VIEW, LONG);
void      WINAPI vwSetViewMenu(VIEW, LPSTR);
void      WINAPI vwSetViewName(VIEW, LPSTR);
void      WINAPI vwSetViewPosition(VIEW, int, int, int, int, WORD);
void      WINAPI vwSetViewProc(VIEW, VIEWPROC);
LONG      WINAPI vwSetViewSelBkColor(VIEW, LONG);
LONG      WINAPI vwSetViewSelTextColor(VIEW, LONG);
void      WINAPI vwSetViewStatus(VIEW, VWFIELD, LONG);
BOOL      WINAPI vwSetViewString(VIEW, LPSTR);
void      WINAPI vwSetViewStyle(VIEW, LONG);
LONG      WINAPI vwSetViewTextColor(VIEW, LONG);
void      WINAPI vwSetViewThisPtr(VIEW, void far *);
VIEW      WINAPI vwSetViewToolBar(HWND, LPCSTR, VIEWPROC, LONG);
void      WINAPI vwSetViewWidth(VIEW, int, BOOL);
void      WINAPI vwSetViewXPos(VIEW, int, BOOL);
void      WINAPI vwSetViewYPos(VIEW, int, BOOL);
HWND      WINAPI vwShowMDIChildView(VIEW);
BOOL      WINAPI vwShowModalView(VIEW);
HWND      WINAPI vwShowView(VIEW);
HWND      WINAPI vwShowViewWindow(VIEW, int);
HGLOBAL   WINAPI vwShowTable(HWND, LPSTR, LONG, int, int, int, int, char, WORD, HINSTANCE, WORD, LPSTR, LPSTR, LONG);
BOOL      WINAPI vwSizeMDIClient(HWND, HWND, BOOL);
BOOL      WINAPI vwSizeToolBars(HWND);
void      WINAPI vwTMToDate(LPSTR, struct tm far *, int, char);
BOOL      WINAPI vwUnhideField(VIEW, VWFIELD);
BOOL      WINAPI vwUnhideTextField(VIEW, VWFIELD, BOOL);
BOOL      WINAPI vwUnhideView(VIEW);
void      WINAPI vwUnprotectField(VIEW, VWFIELD);
void      WINAPI vwUpdateScreen(VIEW);
void      WINAPI vwUpdateApp(VIEW);
BOOL      WINAPI vwUpdateFromViewData(VIEW, VIEW, VWFIELD);
BOOL      WINAPI vwWait(VIEW View, int Time);
#endif // __USESCREEN

#ifdef __cplusplus
}
#endif  /* __cplusplus */

#endif // PVPLUS_H


